@@ -2,12 +2,12 @@ from google.cloud import bigquery
 
 from airflow_commons.glossary import COMMA
 from airflow_commons.logger import LOGGER
-from airflow_commons.sql_resources import (
+from airflow_commons.sql_resources.bigquery import (
     DEDUPLICATION_GET_OLDEST_PARTITION_FIELD_SQL_FILE,
     ARCHIVE_SOURCE_STATEMENT_FILE,
     ARCHIVE_DELETE_WHERE_STATEMENT_FILE,
 )
-from airflow_commons.utils.bigquery_utils import (
+from airflow_commons.utils.bigquery.bigquery_utils import (
     DEFAULT_TIMEOUT,
     DEFAULT_LOCATION,
     DEFAULT_RETURN_TYPE,
@@ -20,7 +20,7 @@ from airflow_commons.utils.bigquery_utils import (
     get_table_ref,
 )
 from airflow_commons.utils.file_utils import read_sql
-from airflow_commons.utils.sql_utils import (
+from airflow_commons.utils.bigquery.sql_utils import (
     get_deduplication_source_statement,
     get_merge_sql,
     get_delete_sql,
