@@ -10,4 +10,6 @@ def read_sql(sql_file: str, **kwargs):
     :return: sql query as string
     """
     with codec_open(sql_file, "r", encoding="utf8") as f:
-        return f.read().format_map(kwargs)
+        if bool(kwargs):
+            return f.read().format_map(kwargs)
+        return f.read()
